Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code

Unified Diff: background.js

Issue 29317001: Relocated icon and redesigned icon popup (Closed)
Patch Set: Merged setBadgeNumber and setBadgeBackgroundColor Created Dec. 13, 2013, 10:36 a.m.
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: background.js
===================================================================
--- a/background.js
+++ b/background.js
@@ -110,7 +110,7 @@
var activeNotification = null;
// Adds or removes page action icon according to options.
function refreshIconAndContextMenu(tab)
{
if(!/^https?:/.test(tab.url))
@@ -128,15 +128,15 @@
iconFilename = excluded ? "icons/abp-19-whitelisted.png" : "icons/abp-19.png";
}
- tab.pageAction.setIcon(iconFilename);
- tab.pageAction.setTitle(ext.i18n.getMessage("name"));
+ tab.browserAction.setIcon(iconFilename);
+ tab.browserAction.setTitle(ext.i18n.getMessage("name"));
iconAnimation.registerTab(tab, iconFilename);
if (localStorage.shouldShowIcon == "false")
- tab.pageAction.hide();
+ tab.browserAction.hide();
else
- tab.pageAction.show();
+ tab.browserAction.show();
if (require("info").platform == "chromium") // TODO: Implement context menus for Safari
// Set context menu status according to whether current tab has whitelisted domain
« no previous file with comments | « _locales/en_US/messages.json ('k') | chrome/background.js » ('j') | lib/stats.js » ('J')
@@ -110,7 +110,7 @@
var activeNotification = null;
-// Adds or removes page action icon according to options.
+// Adds or removes browser action icon according to options.
function refreshIconAndContextMenu(tab)
{

Powered by Google App Engine
This is Rietveld